#include "kiosk.h"

KioskMode::KioskMode( KigDocument& d )
  : KigMode( d )
{

}

KioskMode::~KioskMode()
{

}
void KioskMode::leftClicked( QMouseEvent*, KigWidget* )
{

}
void KioskMode::midClicked( QMouseEvent*, KigWidget* )
{

}
void KioskMode::rightClicked( QMouseEvent*, KigWidget* )
{

}
void KioskMode::leftReleased( QMouseEvent*, KigWidget* )
{

}
void KioskMode::midReleased( QMouseEvent*, KigWidget* )
{

}
void KioskMode::rightReleased( QMouseEvent*, KigWidget* )
{

}
void KioskMode::mouseMoved( QMouseEvent*, KigWidget* )
{

}
